==> vtigercrm-5.3.0p0.tgz: modules/Documents/language/es_mx.lang.php <==
<?php
/*********************************************************************************
 * The contents of this file are subject to the SugarCRM Public License Version 1.1.2
 * ("License"); You may not use this file except in compliance with the
 * License. You may obtain a copy of the License at http://www.sugarcrm.com/SPL
 * Software distributed under the License is distributed on an  "AS IS"  basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License for
 * the specific language governing rights and limitations under the License.
 * The Original Code is:  SugarCRM Open Source
 * The Initial Developer of the Original Code is SugarCRM, Inc.
 * Portions created by SugarCRM are Copyright (C) SugarCRM, Inc.;
 * All Rights Reserved.
 ********************************************************************************
*  Module       : Notes
*  Language     : Español
*  Version      : 504
*  Created Date : 2007-03-30 Last change : 2007-10-10
*  Author       : Rafael Soler
*  Author       : Francisco Hernandez Odin Consultores www.odin.mx
 ********************************************************************************/

$mod_strings = Array(
'LBL_MODULE_NAME'=>'Documentos',
'LBL_MODULE_TITLE'=>'Documentos: Inicio',
'LBL_SEARCH_FORM_TITLE'=>'Buscar Documentos',
'LBL_LIST_FORM_TITLE'=>'Lista de Documentos',
'LBL_NEW_FORM_TITLE'=>'Nuevo Documento',

'LBL_LIST_SUBJECT'=>'Asunto',
'LBL_LIST_CONTACT_NAME'=>'Nombre del Contacto',
'LBL_LIST_RELATED_TO'=>'Relacionado con',
'LBL_LIST_DATE_MODIFIED'=>'Última Modificación',

'LBL_NOTE'=>'Documento:',
'LBL_NOTE_SUBJECT'=>'Asunto del Documento:',
'LBL_CONTACT_NAME'=>'Nombre del Contacto:',
'LBL_PHONE'=>'Teléfono:',
'LBL_SUBJECT'=>'Asunto:',
'LBL_CLOSE'=>'Cerrar:',
'LBL_RELATED_TO'=>'Relacionado con:',
'LBL_EMAIL_ADDRESS'=>'Dirección de Email:',
'LBL_COLON'=>':',

'ERR_DELETE_RECORD'=>"Debe especificar un registro para eliminar la cuenta.",
'LBL_LIST_FILENAME'=>"Nombre Archivo",

// Added for Note(3.2-patch 3) 

'LBL_FILENAME'=>'Adjunto:',
'LBL_NOTE_INFORMATION'=>'Información Básica',
'File Information'=>'Información Archivo',

// Added for 4GA
'LBL_TOOL_FORM_TITLE'=>'Herramientas de Documentos',
// Added for 4GA
'Contact Name'=>'Nombre del Contacto',
'Related To'=>'Relacionado con',
'Subject'=>'Asunto',
'Created Time'=>'Fecha de Alta',
'Modified Time'=>'Última Modificación',
'Document'=>'Documento',
'Note'=>'Notas',
//Added for 4.2 Release -- CustomView
'Related to'=>'Relacionado con',
'Last Modified'=>'Última Modificación',
'File'=>'Archivo',
'LBL_ALL'=>'Todo',
'Title'=>' Asunto',

//Added after 504 for Downloads Module
'LBL_FILE_INFORMATION'=>'Información Archivo',
'LBL_FILE_NAME'=>'Nombre Archivo',
'LBL_FILE_TYPE'=>'Tipo Archivo',
'LBL_FILE_SIZE'=>'Tamaño',
'filelocationtype'=>'Tipo Descarga',
'fileversion'=>'Versión',
'filestatus'=>'Activo',
'filedownloadcount'=>'Número de Descargas',
'os'=>'Plataforma',
'LBL_FOLDER_NAME'=>'Nombre Carpeta',
'LBL_DOWNLOAD_TYPE'=>'Tipo Descarga',
'LBL_INTERNAL'=>'Interno',
'LBL_EXTERNAL'=>'Externo',
'Internal'=>'Interno',
'External'=>'Externo',
'LBL_EXTERNAL_FILE_NAME'=>'Nombre Archivo',
'LBL_FILE_LOCATION'=>'Ubicación Archivo',
'LBL_PD'=>'Dependiente Plataforma',
'LBL_PIND'=>'Independiente Plataforma',
'ChoosePlatform'=>'Elija Plataforma',
'LBL_ACTIVE'=>'Activo',
'LBL_INACTIVE'=>'Inactivo',
'LBL_UPLOAD_BUTTON'=>'Subir',
'architecture'=>'Arquitectura',
'LBL_DOWNLOAD_FILE'=>'Descargar archivo',
'LBL_CHECK_INTEGRITY'=>'Comprobar integridad archivo',
'LBL_EMAIL_FILE'=>'Mandar archivo por Email',
'LBL_CLICK_HERE'=>'Haz Click aquí',
'LBL_TO_ADD_FOLDER'=>'para agregar una nueva carpeta.',
'LBL_DELETE_FOLDER'=>'Eliminar Carpeta',
'LBL_FOLDER_DESC'=>'Descripción',
'LBL_ADD_NEW_FOLDER'=>'Agregar Carpeta',
'LBL_DELETE_DOCUMENTS'=>'Eliminar Documento(s)',
'LBL_MOVE_TO'=>'Mover a',
'File Name'=>'Nombre Archivo',
'File Type'=>'Tipo Archivo',
'File Size'=>'Tamaño',
'LBL_INTERNAL'=>'Interno',
'LBL_URL'=>'URL',
'LBL_EXTERNAL'=>'Externo',
'LBL_EXTERNAL_LNK'=>'Enlace Externo',
'LBL_ACTIVE'=>'Activo',
'LBL_INACTIVE'=>'Inactivo',
'LBL_PLATFORM_INDEPENDENT'=>'Plataforma Independiente',
'LNK_DOWNLOAD'=>'descarga',
'LBL_MOVE_DOCUMENTS'=>'Mover Documento(s)',
'LBL_MOVE'=>'Mover',
'Download Type'=>'Tipo Descarga',
'Version'=>'Versión',
'Active'=>'Activo',
'Download Count'=>'Número Descargas',
'Platform'=>'Plataforma',
'Assigned To'=>'Asignado a',
// Module Sequence Numbering
'Note No' => 'Núm. Documento',
// END

// Documents module
'LBL_EMPTY_FOLDERS' => 'Carpetas Vacías',
'LBL_VIEW_EMPTY_FOLDERS' => 'Ver Carpetas Vacías',
'LBL_NO_DOCUMENTS' => 'Sin Documentos',
'LBL_DESCRIPTION' => 'Descripción',
'FILE_HAS_NO_DATA'=>'El archivo seleccionado no contiene información o es inválido',

'LBL_MAXIMUM_20'=>'Máximo 20',
'LBL_MAXIMUM_50'=>'Máximo 50',

'Document No'=>'Número Documento',
'Folder Name'=>"Nombre de carpeta",

);

?>

==> vtigercrm-5.4.0.tgz: modules/Documents/language/es_mx.lang.php <==
<?php
/*********************************************************************************
 * The contents of this file are subject to the SugarCRM Public License Version 1.1.2
 * ("License"); You may not use this file except in compliance with the
 * License. You may obtain a copy of the License at http://www.sugarcrm.com/SPL
 * Software distributed under the License is distributed on an  "AS IS"  basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License for
 * the specific language governing rights and limitations under the License.
 * The Original Code is:  SugarCRM Open Source
 * The Initial Developer of the Original Code is SugarCRM, Inc.
 * Portions created by SugarCRM are Copyright (C) SugarCRM, Inc.;
 * All Rights Reserved.
 ********************************************************************************
*  Module       : Documents
*  Language     : Español
*  Version      : 5.4.0
*  Created Date : 2007-03-30 Last change : 2012-02-27
*  Author       : Rafael Soler
*  Author       : Francisco Hernandez Odin Consultores www.odin.mx
 ********************************************************************************/

$mod_strings = Array(
'LBL_MODULE_NAME'=>'Documentos',
'LBL_MODULE_TITLE'=>'Documentos: Inicio',
'LBL_SEARCH_FORM_TITLE'=>'Buscar Documentos',
'LBL_LIST_FORM_TITLE'=>'Lista de Documentos',
'LBL_NEW_FORM_TITLE'=>'Nuevo Documento',

'LBL_LIST_SUBJECT'=>'Asunto',
'LBL_LIST_CONTACT_NAME'=>'Nombre del Contacto',
'LBL_LIST_RELATED_TO'=>'Relacionado con',
'LBL_LIST_DATE_MODIFIED'=>'Última Modificación',

'LBL_NOTE'=>'Documento:',
'LBL_NOTE_SUBJECT'=>'Asunto del Documento:',
'LBL_CONTACT_NAME'=>'Nombre del Contacto:',
'LBL_PHONE'=>'Teléfono:',
'LBL_SUBJECT'=>'Asunto:',
'LBL_CLOSE'=>'Cerrar:',
'LBL_RELATED_TO'=>'Relacionado con:',
'LBL_EMAIL_ADDRESS'=>'Dirección de Email:',
'LBL_COLON'=>':',

'ERR_DELETE_RECORD'=>"Debe especificar un registro para eliminar la cuenta.",
'LBL_LIST_FILENAME'=>"Nombre Archivo",

// Added for Note(3.2-patch 3) 

'LBL_FILENAME'=>'Adjunto:',
'LBL_NOTE_INFORMATION'=>'Información Básica',
'File Information'=>'Información Archivo',

// Added for 4GA
'LBL_TOOL_FORM_TITLE'=>'Herramientas de Documentos',
// Added for 4GA
'Contact Name'=>'Nombre del Contacto',
'Related To'=>'Relacionado con',
'Subject'=>'Asunto',
'Created Time'=>'Fecha de Alta',
'Modified Time'=>'Última Modificación',
'Document'=>'Documento',
'Note'=>'Notas',
//Added for 4.2 Release -- CustomView
'Related to'=>'Relacionado con',
'Last Modified'=>'Última Modificación',
'File'=>'Archivo',
'LBL_ALL'=>'Todo',
'Title'=>' Asunto',

//Added after 504 for Downloads Module
'LBL_FILE_INFORMATION'=>'Información Archivo',
'LBL_FILE_NAME'=>'Nombre Archivo',
'LBL_FILE_TYPE'=>'Tipo Archivo',
'LBL_FILE_SIZE'=>'Tamaño',
'filelocationtype'=>'Tipo Descarga',
'fileversion'=>'Versión',
'filestatus'=>'Activo',
'filedownloadcount'=>'Número de Descargas',
'os'=>'Plataforma',
'LBL_FOLDER_NAME'=>'Nombre Carpeta',
'LBL_DOWNLOAD_TYPE'=>'Tipo Descarga',
'LBL_INTERNAL'=>'Interno',
'LBL_EXTERNAL'=>'Externo',
'Internal'=>'Interno',
'External'=>'Externo',
'LBL_EXTERNAL_FILE_NAME'=>'Nombre Archivo',
'LBL_FILE_LOCATION'=>'Ubicación Archivo',
'LBL_PD'=>'Dependiente Plataforma',
'LBL_PIND'=>'Independiente Plataforma',
'ChoosePlatform'=>'Elija Plataforma',
'LBL_ACTIVE'=>'Activo',
'LBL_INACTIVE'=>'Inactivo',
'LBL_UPLOAD_BUTTON'=>'Subir',
'architecture'=>'Arquitectura',
'LBL_DOWNLOAD_FILE'=>'Descargar archivo',
'LBL_CHECK_INTEGRITY'=>'Comprobar integridad archivo',
'LBL_EMAIL_FILE'=>'Enviar archivo por Email',
'LBL_CLICK_HERE'=>'Haz Click aquí',
'LBL_TO_ADD_FOLDER'=>'para agregar una nueva carpeta.',
'LBL_DELETE_FOLDER'=>'Eliminar Carpeta',
'LBL_FOLDER_DESC'=>'Descripción',
'LBL_ADD_NEW_FOLDER'=>'Agregar Carpeta',
'LBL_DELETE_DOCUMENTS'=>'Eliminar Documento(s)',
'LBL_MOVE_TO'=>'Mover a',
'File Name'=>'Nombre Archivo',
'File Type'=>'Tipo Archivo',
'File Size'=>'Tamaño',
'LBL_INTERNAL'=>'Interno',
'LBL_URL'=>'URL',
'LBL_EXTERNAL'=>'Externo',
'LBL_EXTERNAL_LNK'=>'Enlace Externo',
'LBL_ACTIVE'=>'Activo',
'LBL_INACTIVE'=>'Inactivo',
'LBL_PLATFORM_INDEPENDENT'=>'Plataforma Independiente',
'LNK_DOWNLOAD'=>'descarga',
'LBL_MOVE_DOCUMENTS'=>'Mover Documento(s)',
'LBL_MOVE'=>'Mover',
'Download Type'=>'Tipo Descarga',
'Version'=>'Versión',
'Active'=>'Activo',
'Download Count'=>'Número Descargas',
'Platform'=>'Plataforma',
'Assigned To'=>'Asignado a',
// Module Sequence Numbering
'Note No' => 'Núm. Documento',
// END

// Documents module
'LBL_EMPTY_FOLDERS' => 'Carpetas Vacías',
'LBL_VIEW_EMPTY_FOLDERS' => 'Ver Carpetas Vacías',
'LBL_NO_DOCUMENTS' => 'Sin Documentos',
'LBL_DESCRIPTION' => 'Descripción',
'FILE_HAS_NO_DATA'=>'El archivo seleccionado no contiene información o es inválido',

'LBL_MAXIMUM_20'=>'Máximo 20',
'LBL_MAXIMUM_50'=>'Máximo 50',

'Document No'=>'Número Documento',
'Folder Name'=>"Nombre de carpeta",
'Documents' => 'Documentos',
'Documents ID'=>'Id Documento',
);

?>
